==> php54-owncloud-8.0.2.tgz: share/owncloud/apps/files_external/l10n/de.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel für Dropbox korrekt sind.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel für Dropbox korrekt sind.",
    "Please provide a valid Dropbox app key and secret." : "Bitte trage einen gültigen Dropbox-App-Key mit Secret ein.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storage" : "Externer Speicher",
    "Local" : "Lokal",
    "Location" : "Ort",
    "Amazon S3" : "Amazon S3",
    "Key" : "Schlüssel",
    "Secret" : "Geheime Zeichenkette",
    "Bucket" : "Bucket",
    "Amazon S3 and compliant" : "Amazon S3 und kompatible",
    "Access Key" : "Zugriffsschlüssel",
    "Secret Key" : "Sicherheitssschlüssel",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfad-Stil aktivieren",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "Host" : "Host",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Remote subfolder" : "Remote subfolder",
    "Secure ftps://" : "Sicherer ftps://",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Region (optional for OpenStack Object Storage)" : "Region (Optional für Openstack-Objektspeicher)",
    "API Key (required for Rackspace Cloud Files)" : "API-Schlüssel (Erforderlich für Rackspace Cloud-Dateien)",
    "Tenantname (required for OpenStack Object Storage)" : "Mietername (Erforderlich für Openstack-Objektspeicher)",
    "Password (required for OpenStack Object Storage)" : "Passwort (Erforderlich für Openstack-Objektspeicher)",
    "Service Name (required for OpenStack Object Storage)" : "Name der Dienstleistung (Erforderlich für Openstack-Objektspeicher)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "URL des Identitätsendpunktes (Erforderlich für Openstack-Objektspeicher)",
    "Timeout of HTTP requests in seconds" : "Zeitüberschreitung von HTTP-Anfragen in Sekunden",
    "Share" : "Share",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "URL" : "URL",
    "Secure https://" : "Sicherer HTTPS://",
    "Access granted" : "Zugriff gestattet",
    "Error configuring Dropbox storage" : "Fehler beim Einrichten von Dropbox",
    "Grant access" : "Zugriff gestatten",
    "Error configuring Google Drive storage" : "Fehler beim Einrichten von Google Drive",
    "Personal" : "Persönlich",
    "System" : "System",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Saved" : "Gespeichert",
    "<b>Note:</b> " : "<b>Hinweis:</b> ",
    "and" : "und",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die cURL-Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die FTP Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> \"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can configure external storages in the personal settings" : "Du kannst externe Speicher in den persönlichen Einstellungen konfigurieren",
    "Name" : "Name",
    "Storage type" : "Du hast noch keinen externen Speicher",
    "Scope" : "Anwendungsbereich",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Delete" : "Löschen",
    "Enable User External Storage" : "Externen Speicher für Benutzer aktivieren",
    "Allow users to mount the following external storage" : "Erlaube es Benutzern, den folgenden externen Speicher einzubinden"
},
"nplurals=2; plural=(n != 1);");

==> php54-owncloud-8.1.0.tgz: share/owncloud/apps/files_external/l10n/de.js <==
OC.L10N.register(
    "files_external",
    {
    "Fetching request tokens failed. Verify that your Dropbox app key and secret are correct." : "Abrufen des Anfrage-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel für Dropbox korrekt sind.",
    "Fetching access tokens failed. Verify that your Dropbox app key and secret are correct." : "Abrufen des Zugriff-Tokens fehlgeschlagen. Stelle bitte sicher, dass der Anwendungsschlüssel und Sicherheitsschlüssel für Dropbox korrekt sind.",
    "Please provide a valid Dropbox app key and secret." : "Bitte trage einen gültigen Dropbox-App-Key mit Secret ein.",
    "Step 1 failed. Exception: %s" : "Schritt 1 fehlgeschlagen. Fehlermeldung: %s",
    "Step 2 failed. Exception: %s" : "Schritt 2 fehlgeschlagen. Fehlermeldung: %s",
    "External storage" : "Externer Speicher",
    "Local" : "Lokal",
    "Location" : "Ort",
    "Amazon S3" : "Amazon S3",
    "Key" : "Schlüssel",
    "Secret" : "Geheime Zeichenkette",
    "Bucket" : "Bucket",
    "Amazon S3 and compliant" : "Amazon S3 und kompatible",
    "Access Key" : "Zugriffsschlüssel",
    "Secret Key" : "Sicherheitssschlüssel",
    "Hostname" : "Host-Name",
    "Port" : "Port",
    "Region" : "Region",
    "Enable SSL" : "SSL aktivieren",
    "Enable Path Style" : "Pfad-Stil aktivieren",
    "App key" : "App-Schlüssel",
    "App secret" : "Geheime Zeichenkette der App",
    "Host" : "Host",
    "Username" : "Benutzername",
    "Password" : "Passwort",
    "Remote subfolder" : "Entfernter Unterordner",
    "Secure ftps://" : "Sicherer ftps://",
    "Client ID" : "Client-ID",
    "Client secret" : "Geheime Zeichenkette des Client",
    "OpenStack Object Storage" : "Openstack-Objektspeicher",
    "Region (optional for OpenStack Object Storage)" : "Region (Optional für Openstack-Objektspeicher)",
    "API Key (required for Rackspace Cloud Files)" : "API-Schlüssel (Erforderlich für Rackspace Cloud-Dateien)",
    "Tenantname (required for OpenStack Object Storage)" : "Mietername (Erforderlich für Openstack-Objektspeicher)",
    "Password (required for OpenStack Object Storage)" : "Passwort (Erforderlich für Openstack-Objektspeicher)",
    "Service Name (required for OpenStack Object Storage)" : "Name der Dienstleistung (Erforderlich für Openstack-Objektspeicher)",
    "URL of identity endpoint (required for OpenStack Object Storage)" : "URL des Identitätsendpunktes (Erforderlich für Openstack-Objektspeicher)",
    "Timeout of HTTP requests in seconds" : "Zeitüberschreitung von HTTP-Anfragen in Sekunden",
    "Share" : "Share",
    "SMB / CIFS using OC login" : "SMB / CIFS mit OC-Login",
    "Username as share" : "Benutzername als Freigabe",
    "URL" : "URL",
    "Secure https://" : "Sicherer HTTPS://",
    "SFTP with secret key login" : "SFTP mit dem Login über einen geheimen Schlüssel",
    "Public key" : "Öffentlicher Schlüssel",
    "Storage with id \"%i\" not found" : "Der Speicher mit der ID „%i“ wurde nicht gefunden",
    "Invalid mount point" : "Ungültiger mount point",
    "Invalid storage backend \"%s\"" : "Ungültiges Speicher-Backend „%s“",
    "Access granted" : "Zugriff gestattet",
    "Error configuring Dropbox storage" : "Fehler beim Einrichten von Dropbox",
    "Grant access" : "Zugriff gestatten",
    "Error configuring Google Drive storage" : "Fehler beim Einrichten von Google Drive",
    "Personal" : "Persönlich",
    "System" : "System",
    "Enable encryption" : "Verschlüsselung aktivieren",
    "Enable previews" : "Vorschau aktivieren",
    "Check for changes" : "Auf Änderungen überprüfen",
    "Never" : "Nie",
    "Once every direct access" : "Einmal bei jedem Direktzugriff",
    "Every time the filesystem is used" : "Immer, wenn das Dateisystem benutzt wird",
    "All users. Type to select user or group." : "Alle Benutzer. Benutzer oder Gruppe zur Auswahl eingeben.",
    "(group)" : "(group)",
    "Saved" : "Gespeichert",
    "Generate keys" : "Schlüssel erzeugen",
    "Error generating key pair" : "Fehler beim Erzeugen des Schlüsselpaares",
    "<b>Note:</b> " : "<b>Hinweis:</b> ",
    "and" : "und",
    "<b>Note:</b> The cURL support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die cURL-Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> The FTP support in PHP is not enabled or installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> Die FTP Unterstützung von PHP ist nicht aktiviert oder installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "<b>Note:</b> \"%s\" is not installed. Mounting of %s is not possible. Please ask your system administrator to install it." : "<b>Hinweis:</b> \"%s\" ist nicht installiert. Das Hinzufügen von %s ist nicht möglich. Bitte wende Dich sich zur Installation an Deinen Systemadministrator.",
    "No external storage configured" : "Kein externer Speicher konfiguriert",
    "You can add external storages in the personal settings" : "Du kannst externe Speicher in den persönlichen Einstellungen hinzufügen",
    "Name" : "Name",
    "Storage type" : "Du hast noch keinen externen Speicher",
    "Scope" : "Anwendungsbereich",
    "External Storage" : "Externer Speicher",
    "Folder name" : "Ordnername",
    "Configuration" : "Konfiguration",
    "Available for" : "Verfügbar für",
    "Add storage" : "Speicher hinzufügen",
    "Advanced settings" : "Erweiterte Einstellungen",
    "Delete" : "Löschen",
    "Enable User External Storage" : "Externen Speicher für Benutzer aktivieren",
    "Allow users to mount the following external storage" : "Erlaube es Benutzern, den folgenden externen Speicher einzubinden"
},
"nplurals=2; plural=(n != 1);");
